@@ -24,6 +24,11 @@ my @optionals = (
       provides default attribute values, and which can be encrypted with
       gpg2. If you do not intend to make use of the identity file,
       Config::Identity is not needed.
+EOD
+    __any( 'Browser::Open'		=> <<'EOD' ),
+      This module is being phased in as the only supported way to
+      display web-based help. If you intend to leave the 'webcmd'
+      attribute false, this module is not needed.
 EOD
     __any( 'Time::HiRes'		=> <<'EOD' ),
       This module is used for more precise throttling of Space Track
@@ -184,7 +189,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2016 by Thomas R. Wyant, III
+Copyright (C) 2010-2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
